@@ -3,4 +3,4 @@ def print_lolz(the_list):
 		if isinstance(item,list):
 			print_lolz(item)
 		else:
-			print ">>", item
+			print "$$", item
